@@ -19,12 +19,10 @@
 
 #include "bookmarklistview.h"
 #include "globalbookmarkmanager.h"
-#include "kbookmarkmodel/commands.h"
 #include "kbookmarkmodel/model.h"
 #include "settings.h"
 #include "toplevel.h" // for KEBApp
 
-#include <QBrush>
 #include <QContextMenuEvent>
 #include <QHeaderView>
 #include <QItemSelection>
